@@ -1,5 +1,5 @@
 
-# This file is part of CovidPy v0.0.3.
+# This file is part of CovidPy v0.0.5.
 #
 # The project has been distributed in the hope it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,4 +26,9 @@ class QRCode:
     def decode(self):
         self.__cpyinstance.decode(self)
     def verify(self):
-        self.__cpyinstance.verify(self)
\ No newline at end of file
+        self.__cpyinstance.verify(self)
+
+class VerifyResult:
+    def __init__(self, is_valid:bool, is_revoked:bool):
+        self.valid = is_valid
+        self.revoked = is_revoked
\ No newline at end of file
